package com.glxp.mipsdl.client.axxyy;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Unmarshaller;
import java.io.StringReader;
import java.util.List;

/**
 * @author : zhuzhu
 * @date : 2025/2/28 16:03
 * @modyified By :
 */

public class JAXBUtil {

//    /**
//     * 将XML字符串反序列化为指定类型的Java对象，并返回该对象的data字段值。
//     *
//     * @param clazz 目标Java类
//     * @param xml XML字符串
//     * @param <T> 泛型，表示目标类的类型
//     * @return 目标对象的data字段值
//     * @throws JAXBException 如果JAXB操作失败
//     */
//    public static <T> Object unmarshalAndGetResult(Class<T> clazz, String xml) throws JAXBException {
//        // 创建JAXB上下文
//        JAXBContext jaxbContext = JAXBContext.newInstance(clazz);
//        // 创建Unmarshaller
//        Unmarshaller unmarshaller = jaxbContext.createUnmarshaller();
//
//        // 反序列化XML为Java对象
//        T object = (T) unmarshaller.unmarshal(new StringReader(xml));
//
//        // 调用目标对象的getData()方法并返回结果
//        return ((ProductVo) object).getData();
//    }

    /**
     * 将XML字符串反序列化为指定类型的Java对象，并返回data字段的值。
     *
     * @param clazz 目标Java类（如ProductVo.class）
     * @param dataClass data字段中元素的类型（如Item.class）
     * @param xml XML字符串
     * @param <T> 泛型，表示data字段中元素的类型
     * @return data字段的值（List<T>）
     * @throws JAXBException 如果JAXB操作失败
     */
    public static <T> List<T> unmarshalAndGetList(Class<?> clazz, Class<T> dataClass, String xml) throws JAXBException {
        // 创建JAXB上下文
        JAXBContext jaxbContext = JAXBContext.newInstance(clazz, dataClass);
        // 创建Unmarshaller
        Unmarshaller unmarshaller = jaxbContext.createUnmarshaller();

        // 反序列化XML为Java对象
        Object object = unmarshaller.unmarshal(new StringReader(xml));

        // 假设反序列化后的对象是ProductVo类型
        ProductVo<T> productVo = (ProductVo<T>) object;

        // 返回data字段的值
        return productVo.getData();
    }

//    public static void main(String[] args) {
//        try {
//            // 示例用法
//            String xml = "<ProductVo><data>Example Data</data></ProductVo>";
//            Object result = unmarshalAndGetResult(ProductVo.class, xml);
//            System.out.println("Result: " + result);
//        } catch (JAXBException e) {
//            e.printStackTrace();
//        }
//    }
}
